# python-pie

Python-pie reads key-value pairs from a `.env` file and can set them as environment
variables. It helps in the development of applications following the

## Getting Started

```shell
pip install python-pie
```
